@@ -5,11 +5,15 @@
 ##' published packages on CRAN. The results of the checks can be
 ##' summarized as a tibble (see \code{\link{cran_results}}), or
 ##' as \dQuote{pretty} terminal output (see
-##' \code{\link{summary_cran_results}}).  The package also provides
+##' \code{\link{summary_cran_results}}). The package provides
 ##' functions to view the logs of the CRAN check results (see
 ##' \code{\link{cran_details}}), or to visit the web pages hosted
 ##' by CRAN (see \code{\link{visit_cran_check}}).
+##' You can also use \code{foghorn} to follow your package during
+##' its submission process to CRAN or to WinBuilder with,
+##' \code{\link{cran_incoming}} and \code{\link{winbuilder_queue}}.
 ##'
 ##' @name foghorn
 ##' @docType package
-NULL
+##' @keywords internal
+"_PACKAGE"
